.. -*- mode: rst -*-

|CircleCI|_ |ReadTheDocs|_

.. |CircleCI| image:: https://circleci.com/gh/hrolfrc/bib-ami.svg?style=shield
.. _CircleCI: https://circleci.com/gh/hrolfrc/bib-ami

.. |ReadTheDocs| image:: https://readthedocs.org/projects/bib-ami/badge/?version=latest
.. _ReadTheDocs: https://bib-ami.readthedocs.io/en/latest/?badge=latest

BibClean
#####################################

Clean and update your bibtex .bib files

Contact
------------------
Rolf Carlson hrolfrc@gmail.com

Install
------------------
Use pip to install calfcv.

``pip install bib-ami``

Introduction
------------------
This is the bib-ami project.

Example
===========

.. code:: ipython2

    from bib-ami import bib_ami
